@@ -1,4 +1,5 @@
 # coding: utf-8
+import re
 import json
 import datetime
 import decimal
@@ -24,3 +25,7 @@ class JSONEncoder(json.JSONEncoder):
             return str(o)
         else:
             return super(JSONEncoder, self).default(o)
+
+def cc_to_(name):
+        s1 = re.sub('(.)([A-Z][a-z]+)', r'\1_\2', name)
+        return re.sub('([a-z0-9])([A-Z])', r'\1_\2', s1).lower()
